@@ -36,7 +36,6 @@
 #include <QFileSystemWatcher>
 
 #include "projectmodel.h"
-#include "webquerycontroller.h"
 
 #include <knotification.h>
 
@@ -53,6 +52,8 @@ QString getMailingList()
         return QLatin1String("kde-i18n-ca@kde.org");
     if (lang.startsWith(QLatin1String("de")))
         return QLatin1String("kde-i18n-de@kde.org");
+    if (lang.startsWith(QLatin1String("fr")))
+        return QLatin1String("kde-francophone@kde.org");
     if (lang.startsWith(QLatin1String("hu")))
         return QLatin1String("kde-l10n-hu@kde.org");
     if (lang.startsWith(QLatin1String("tr")))
